@@ -16,13 +16,15 @@
 spotReportDefault <- function(spotConfig) {		
 	spotWriteLines(spotConfig$io.verbosity,2,"  Entering spotReportDefault");	
 	rawB <- spotGetRawDataMatrixB(spotConfig);
-	print(summary(rawB));
+	spotPrint(spotConfig$io.verbosity,1,summary(rawB));
 	mergedData <- spotPrepareData(spotConfig)
 	mergedB <- spotGetMergedDataMatrixB(mergedData, spotConfig);	
 	spotConfig=spotWriteBest(mergedData, spotConfig);
 	C1=spotConfig$alg.currentBest[nrow(spotConfig$alg.currentBest),]
-	cat(sprintf("\n Best solution found with %d evaluations:\n",nrow(rawB)));
-	print(C1);		
+	#cat(sprintf("\n Best solution found with %d evaluations:\n",nrow(rawB)));
+	spotWriteLines(spotConfig$io.verbosity,1," ");
+	spotPrint(spotConfig$io.verbosity,1,paste("Best solution found with ",nrow(rawB)," evaluations:",sep=""));
+	spotPrint(spotConfig$io.verbosity,1,C1);		
 	fit.tree <- rpart(y ~ ., data= rawB)		
 	if (!is.null(fit.tree$splits)){
 		if(spotConfig$report.io.pdf==TRUE){ #if pdf should be created
@@ -32,7 +34,7 @@ spotReportDefault <- function(spotConfig) {
 			draw.tree(fit.tree, digits=4)	
 			dev.off() #close pdf device
 		}
-		if(spotConfig$report.io.screen==TRUE) #if graphic should be on screen
+		if(spotConfig$report.io.screen==TRUE && spotConfig$io.verbosity>0) #if graphic should be on screen
 		{
 			x11()
 			par(mfrow=c(1,1), xpd=NA)
